@@ -10,9 +10,8 @@ from mstr_classes import rep
 from mstr_classes import mstr_global
 from mstr_classes import get_conn
 from datetime import datetime
-import helper
+from helper import str_func
 import pandas as pd
-import json
 
 
 class open_conn():
@@ -46,7 +45,7 @@ class cubes:
 class bld_short_cuts:
 
     def __init__(self):
-        self.str=helper.str_func()
+        self.str= str_func()
         self.rep = rep()
         self.glob = mstr_global()
 
@@ -132,7 +131,7 @@ class get_change_log:
         #self.chg_log_dep_bool = change_query["chg_log_dep_bool"]
         self.short_cut_folder_id=None
 
-        self.str=helper.str_func()
+        self.str= str_func()
         self.rep = rep()
         self.glob = mstr_global()
 
